// Copyright (C) 2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the GNU LGPL license.





// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->

//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction
//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction
////////////////////////////////////////


// Get default dimension
option = 4;
nprob = 1;
computed=intprb_getfunc([],[],[],[],nprob,option);
assert_equal ( computed , 10 );

// Get default parameters
option = 7;
nprob = 1;
n=intprb_getfunc([],[],[],[],nprob,4);
computed=intprb_getfunc([],n,[],[],nprob,option);
assert_equal ( computed , [] );


// Get f at x for Sum test case
p=intprb_getfunc([],[],[],[],nprob,4);
p=intprb_getfunc([],n,[],[],nprob,7);
m = 5;
x = grand(m,n,"def");
option = 1;
nprob = 1;
f=intprb_getfunc(m,n,x,p,nprob,option);
assert_equal ( size(f) , [m 1] );

// Get expectation for Sum test case
n = 10;
m = [];
x = [];
p = [];
option = 2;
nprob = 1;
e=intprb_getfunc(m,n,x,p,nprob,option);
assert_equal ( e , 0 );

// Get variance for Sum test case
n = 10;
m = [];
x = [];
p = [];
option = 3;
nprob = 1;
computed=intprb_getfunc(m,n,x,p,nprob,option);
assert_equal ( computed , 1 );

// See if the problem has variable size
n = [];
m = [];
x = [];
p = [];
option = 6;
nprob = 1;
computed=intprb_getfunc(m,n,x,p,nprob,option);
assert_equal ( computed , %t );

// Get full name
n = [];
m = [];
x = [];
p = [];
option = 5;
nprob = 1;
computed=intprb_getfunc(m,n,x,p,nprob,option);
assert_equal ( computed , "Sum of X" );


