// Copyright (C) 2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the GNU LGPL license.





// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->


//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction
//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction
////////////////////////////////////////

// Get all short names
name = intprb_getname();
assert_equal ( typeof(name) , "string" );
assert_equal ( size(name,"c") , 1 );
assert_equal ( size(name,"r") > 1 , %t );

// Get name for Sum test case
name = intprb_getname(1);
assert_equal ( name , "sum" );
name = intprb_getname(1,%f);
assert_equal ( name , "sum" );
name = intprb_getname(1,%t);
assert_equal ( name , "Sum of X" );

// Check that all names can be retrieved
nprobmax = intprb_getproblems();
for nprob = 1 : nprobmax
  name = intprb_getname(nprob);
  assert_equal ( typeof(name) , "string" );
  assert_equal ( size(name) , [1 1] );
  name = intprb_getname(nprob,%t);
  assert_equal ( typeof(name) , "string" );
  assert_equal ( size(name) , [1 1] );
end

// See a case of error
nprobmax = intprb_getproblems();
cmd = "name = intprb_getname(-1)";
execstr(cmd,"errcatch");
[str,errcode] = lasterror();
expected = msprintf("intprb_getname: The input argument nprob is -1 but should be between 1 and %d.",nprobmax);
assert_equal ( str , expected );
//
// Get all names at once
nprobmax = intprb_getproblems();
name = intprb_getname(1:nprobmax);
assert_equal ( size(name) , [nprobmax 1] );

