// Copyright (C) 2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the GNU LGPL license.





// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->


//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if ( and(expected==0.0) ) then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if ( shift < epsilon ) then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction
//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if ( and ( computed==expected ) ) then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction
////////////////////////////////////////

//
// Basic test case : two non-empty matrices xa and xb.
xa = (1 : 10)';
na = size(xa,"*");
xb = (11 : 20)';
nb = size(xb,"*");
mua = mean(xa);
mub = mean(xb);
va = variance(xa);
vb = variance(xb);
[ mu , var ] = intprb_muvblockupdate ( na , nb , mua , mub , va , vb );
x = [xa' xb']';
assert_close ( mean(x) , mu , %eps );
assert_close ( variance(x) , var , %eps );

//
// Practical test case : an empty xa with a non-empty xb.
// This is used when the update is applied for the first time.
xa = [];
na = 0;
xb = (11 : 20)';
nb = size(xb,"*");
mua = 0;
mub = mean(xb);
va = 0;
vb = variance(xb);
[ mu , var ] = intprb_muvblockupdate ( na , nb , mua , mub , va , vb );
x = [xa' xb']';
assert_close ( mean(x) , mu , %eps );
assert_close ( variance(x) , var , %eps );

//
// Ten loops to simulate a practical use.
// The vectors xb are generated on the fly and the 
// mean and variance is updated by block.
// The largest mean and variance computed is of size nb=5,
// instead of the total size n=50.
grand("setsd",123456);
n = 0;
mu = 0;
var = 0;
x = [];
nb = 5;
for k = 1 : 10
  xb = grand(nb,1,"def");
  mub = mean(xb);
  vb = variance(xb);
  [ mu , var ] = intprb_muvblockupdate ( n , nb , mu , mub , var , vb );
  x = [x' xb']';
  n = n + nb;
end
assert_close ( mean(x) , mu , %eps );
assert_close ( variance(x) , var , 10 * %eps );


